@@ -31,11 +31,11 @@
 #' }
 kullback_leibler <-
 function(x, y = NULL){
-    if(is(x, "wfdf")){
-        if (is(x, "t.df")) {
+    if(methods::is(x, "wfdf")){
+        if (methods::is(x, "t.df")) {
             x <- x[, -c(1)]
         } else {
-             if (is(x, "m.df")) { 
+             if (methods::is(x, "m.df")) { 
                  x <- x[-nrow(x), -c(1, ncol(x))]
              } 
         }
@@ -100,6 +100,6 @@ kl <- function(x, y){
     y1 <- y/sum(y)
     x1[x1==0] <- NA
     y1[y1==0] <- NA
-    z <- na.omit(data.frame(x1, y1))
+    z <- stats::na.omit(data.frame(x1, y1))
     sum(z[, 1] * log(z[, 1]/z[, 2]))
 }
